==> jc-1.4.0.tar.gz: java/lang/Void.h <==
// public final class java.lang.Void

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c62aae2c93066d52 java_lang_Void

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Void_H_
#define _JC_java_lang_Void_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_Void$sub_refs	_jc_java_lang_Void$sub_refs;
typedef struct _jc_java_lang_Void$sub_nonrefs	_jc_java_lang_Void$sub_nonrefs;
typedef struct _jc_java_lang_Void$refs	_jc_java_lang_Void$refs;
typedef struct _jc_java_lang_Void$nonrefs	_jc_java_lang_Void$nonrefs;
typedef struct _jc_java_lang_Void$object	_jc_java_lang_Void$object;

typedef struct _jc_java_lang_Void$fields_struct	_jc_java_lang_Void$fields_struct;
typedef const struct _jc_java_lang_Void$vmethods	_jc_java_lang_Void$vmethods;
typedef const struct _jc_java_lang_Void$vtable	_jc_java_lang_Void$vtable;
typedef const struct _jc_java_lang_Void$vtype	_jc_java_lang_Void$vtype;

// Class fields structure
struct _jc_java_lang_Void$fields_struct {
	struct _jc_java_lang_Class$object	*TYPE;
};
extern _jc_java_lang_Void$fields_struct _jc_java_lang_Void$class_fields;

// Constructors
extern void _jc_java_lang_Void$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Void$object *);

// Static methods
extern void _jc_java_lang_Void$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_lang_Void$vmethods {
};

// Vtable
struct _jc_java_lang_Void$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Void$vmethods	java_lang_Void;
};

// Vtype
struct _jc_java_lang_Void$vtype {
	_jc_type			type;
	_jc_java_lang_Void$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Void$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Void$refs {
    _jc_java_lang_Void$sub_refs	java_lang_Void;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Void$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Void$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Void$sub_nonrefs	java_lang_Void;
};

// Object instance structure
struct _jc_java_lang_Void$object {
	_jc_java_lang_Void$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Void$vtype	*vtype;
	_jc_java_lang_Void$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Void$vtype _jc_java_lang_Void$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Void, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Void$class_object;

#endif	/* _JC_java_lang_Void_H_ */

==> jc-1.4.6.tar.gz: java/lang/Void.h <==
// public final class java.lang.Void

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c62aae2c93066d52 java_lang_Void

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Void_H_
#define _JC_java_lang_Void_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_Void$sub_refs	_jc_java_lang_Void$sub_refs;
typedef struct _jc_java_lang_Void$sub_nonrefs	_jc_java_lang_Void$sub_nonrefs;
typedef struct _jc_java_lang_Void$refs	_jc_java_lang_Void$refs;
typedef struct _jc_java_lang_Void$nonrefs	_jc_java_lang_Void$nonrefs;
typedef struct _jc_java_lang_Void$object	_jc_java_lang_Void$object;

typedef struct _jc_java_lang_Void$fields_struct	_jc_java_lang_Void$fields_struct;
typedef const struct _jc_java_lang_Void$vmethods	_jc_java_lang_Void$vmethods;
typedef const struct _jc_java_lang_Void$vtable	_jc_java_lang_Void$vtable;
typedef const struct _jc_java_lang_Void$vtype	_jc_java_lang_Void$vtype;

// Class fields structure
struct _jc_java_lang_Void$fields_struct {
	struct _jc_java_lang_Class$object	*TYPE;
};
extern _jc_java_lang_Void$fields_struct _jc_java_lang_Void$class_fields;

// Constructors
extern void _jc_java_lang_Void$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Void$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_lang_Void$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_Void$vmethods {
};

// Vtable
struct _jc_java_lang_Void$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Void$vmethods	java_lang_Void;
};

// Vtype
struct _jc_java_lang_Void$vtype {
	_jc_type			type;
	_jc_java_lang_Void$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Void$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Void$refs {
    _jc_java_lang_Void$sub_refs	java_lang_Void;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Void$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Void$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Void$sub_nonrefs	java_lang_Void;
};

// Object instance structure
struct _jc_java_lang_Void$object {
	_jc_java_lang_Void$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Void$vtype	*vtype;
	_jc_java_lang_Void$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Void$vtype _jc_java_lang_Void$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Void, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Void$class_object;

#endif	/* _JC_java_lang_Void_H_ */
